MethodChannelFlutterSystemRingtones class
An implementation of FlutterSystemRingtonesPlatform that uses method channels.
- Inheritance
-
- Object
- FlutterSystemRingtonesPlatform
- MethodChannelFlutterSystemRingtones
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAlarms(
) → Future< List< Ringtone> ?> -
invokes the getAlarms method on the native platform, which returns a list of hashmaps that
get converted to Ringtone objects containing platform alarm sounds.
override
-
getNotifications(
) → Future< List< Ringtone> ?> -
invokes the getNotifications method on the native platform, which returns a list of hashmaps that
get converted to Ringtone objects containing platform notification sounds.
override
-
getRingtones(
) → Future< List< Ringtone> ?> -
invokes the getRingtones method on the native platform, which returns a list of hashmaps that
get converted to Ringtone objects containing platform ringtone sounds.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
play(
String uri) → Future< void> -
invokes the play method on the native platform, which plays the sound at
uri. Any currently playing sound is stopped first.override -
stop(
) → Future< void> -
invokes the stop method on the native platform, stopping the currently
playing sound, if any.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited