FlutterSystemRingtonesPlatform class abstract
The interface that platform-specific implementations of flutter_system_ringtones must implement.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAlarms(
) → Future< List< Ringtone> ?> -
getNotifications(
) → Future< List< Ringtone> ?> -
getRingtones(
) → Future< List< Ringtone> ?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
play(
String uri) → Future< void> -
stop(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ FlutterSystemRingtonesPlatform
-
The instance of FlutterSystemRingtonesPlatform to use.
getter/setter pair